@@ -5,7 +5,7 @@
 # Usage:
 #	python getartist.py artist-id
 #
-# $Id: getartist.py 9734 2008-03-09 13:15:07Z matt $
+# $Id: getartist.py 11853 2009-07-21 09:26:50Z luks $
 #
 import sys
 import logging
@@ -28,7 +28,7 @@ try:
 	#
 	inc = ws.ArtistIncludes(
 		releases=(m.Release.TYPE_OFFICIAL, m.Release.TYPE_ALBUM),
-		tags=True)
+		tags=True, releaseGroups=True)
 	artist = q.getArtistById(sys.argv[1], inc)
 except ws.WebServiceError, e:
 	print 'Error:', e
@@ -42,10 +42,9 @@ print "UniqueName :", artist.getUniqueName()
 print "Type       :", artist.type
 print "BeginDate  :", artist.beginDate
 print "EndDate    :", artist.endDate
-print "Tags       :", ', '.join(t.value for t in artist.tags)
+print "Tags       :", ', '.join([t.value for t in artist.tags])
 print
 
-
 if len(artist.getReleases()) == 0:
 	print "No releases found."
 else:
@@ -59,6 +58,23 @@ for release in artist.getReleases():
 	print "Text      :", release.textLanguage, '/', release.textScript
 	print "Types     :", release.types
 
+print
+
+if len(artist.getReleaseGroups()) == 0:
+	print
+	print "No release groups found."
+else:
+	print
+	print "Release groups:"
+
+for rg in artist.getReleaseGroups():
+	print
+	print "Id        :", rg.id
+	print "Title     :", rg.title
+	print "Type      :", rg.type
+
+print
+
 #
 # Using the release IDs and Query.getReleaseById(), you could now request 
 # those releases, including the tracks, release events, the associated
