@@ -9,7 +9,7 @@
 #	http://musicbrainz.org/release/290e10c5-7efc-4f60-ba2c-0dfc0208fbf5
 #	http://musicbrainz.org/release/fa9f1bdd-495f-41b9-8944-1a766da29120
 #
-# $Id: getrelease.py 9320 2007-08-11 08:47:35Z matt $
+# $Id: getrelease.py 11853 2009-07-21 09:26:50Z luks $
 #
 import sys
 import logging
@@ -33,7 +33,7 @@ try:
 	# the track list.
 	#
 	inc = ws.ReleaseIncludes(artist=True, releaseEvents=True, labels=True,
-			discs=True, tracks=True)
+			discs=True, tracks=True, releaseGroup=True)
 	release = q.getReleaseById(sys.argv[1], inc)
 except ws.WebServiceError, e:
 	print 'Error:', e
@@ -55,6 +55,12 @@ if release.artist:
 	print "  Name      :", release.artist.name
 	print "  SortName  :", release.artist.sortName
 
+if release.releaseGroup:
+	print
+	print "Release Group:"
+	print "  Id        :", release.releaseGroup.id
+	print "  Title     :", release.releaseGroup.title
+	print "  Type      :", release.releaseGroup.type
 
 # Release events are the dates and times when a release took place.
 # We also have the catalog numbers and barcodes for some releases.
