@@ -77,13 +77,16 @@ class ParseTrackTest(unittest.TestCase):
 		self.assertEquals(len(puids), 7)
 		self.assertEquals(puids[0], 'c2a2cee5-a8ca-4f89-a092-c3e1e65ab7e6')
 		self.assertEquals(puids[6], '42ab76ea-5d42-4259-85d7-e7f2c69e4485')
+		
+		isrcs = track.isrcs
+		self.assertEquals(len(isrcs), 1)
+		self.assertEquals(isrcs[0], 'USPR37300012')
 
 		releases = track.getReleases()
 		self.assertEquals(len(releases), 1)
 		self.assertEquals(releases[0].getTitle(), 'Little Earthquakes')
 		self.assertEquals(releases[0].getTracksOffset(), 2)
 
-
 	def testSearchResults(self):
 		f = os.path.join(VALID_TRACK_DIR, 'search_result_1.xml')
 		md = MbXmlParser().parse(f)
